@@ -1,6 +1,6 @@
 ;; -*-emacs-lisp-*-
 ;;
-;; Emacs startup file for the Debian GNU/Linux #PACKAGE# package
+;; Emacs startup file for the Debian #PACKAGE# package
 ;;
 ;; Originally contributed by Nils Naumann <naumann@unileoben.ac.at>
 ;; Modified by Dirk Eddelbuettel <edd@debian.org>
@@ -11,8 +11,9 @@
 ;; xemacs19, emacs20, xemacs20...).  The compiled code is then
 ;; installed in a subdirectory of the respective site-lisp directory.
 ;; We have to add this to the load-path:
-(setq load-path (cons (concat "/usr/share/"
-                              (symbol-name flavor)
-			      "/site-lisp/#PACKAGE#") load-path))
-
+(let ((package-dir (concat "/usr/share/"
+                           (symbol-name flavor)
+                           "/site-lisp/#PACKAGE#")))
+  (when (file-directory-p package-dir)
+        (setq load-path (cons package-dir load-path))))
 
