@@ -4,19 +4,23 @@
 #		This file should be used to construct scripts for /etc/init.d.
 #
 #		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
-#		Modified for Debian GNU/Linux
+#		Modified for Debian 
 #		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
 #
-# Version:	@(#)skeleton  1.8  03-Mar-1998  miquels@cistron.nl
+# Version:	@(#)skeleton  1.9  26-Feb-2001  miquels@cistron.nl
 #
-# This file was automatically customized by dh-make on #DATE#
 
-PATH=/sbin:/bin:/usr/sbin:/usr/bin
+PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
 DAEMON=/usr/sbin/#PACKAGE#
 NAME=#PACKAGE#
 DESC=#PACKAGE#
 
-test -f $DAEMON || exit 0
+test -x $DAEMON || exit 0
+
+# Include #PACKAGE# defaults if available
+if [ -f /etc/default/#PACKAGE# ] ; then
+	. /etc/default/#PACKAGE#
+fi
 
 set -e
 
@@ -24,12 +28,12 @@ case "$1" in
   start)
 	echo -n "Starting $DESC: "
 	start-stop-daemon --start --quiet --pidfile /var/run/$NAME.pid \
-		--exec $DAEMON
+		--exec $DAEMON -- $DAEMON_OPTS
 	echo "$NAME."
 	;;
   stop)
 	echo -n "Stopping $DESC: "
-	start-stop-daemon --oknodo --stop --quiet --pidfile /var/run/$NAME.pid \
+	start-stop-daemon --stop --quiet --pidfile /var/run/$NAME.pid \
 		--exec $DAEMON
 	echo "$NAME."
 	;;
@@ -56,7 +60,7 @@ case "$1" in
 		/var/run/$NAME.pid --exec $DAEMON
 	sleep 1
 	start-stop-daemon --start --quiet --pidfile \
-		/var/run/$NAME.pid --exec $DAEMON
+		/var/run/$NAME.pid --exec $DAEMON -- $DAEMON_OPTS
 	echo "$NAME."
 	;;
   *)
